@@ -3,15 +3,12 @@
 # Author: Martin Senger <martin.senger@gmail.com>
 # For copyright and disclaimer see below.
 #
-# $Id: Base.pm,v 1.6 2008/11/06 18:32:33 kawas Exp $
+# $Id: Base.pm,v 1.1 2006/10/13 21:51:16 senger Exp $
 #-----------------------------------------------------------------
 
 package MOSES::MOBY::Base;
 
 use strict;
-
-use HTTP::Date;
-
 use vars qw( $VERSION $Revision $AUTOLOAD @EXPORT @ISA );
 use vars qw( $LOG $LOGGER_NAME $CONFIG_NAMESPACE );
 
@@ -34,8 +31,8 @@ BEGIN {
     @ISA = qw( Exporter );
     @EXPORT = qw( $LOG );
 
-    $VERSION = sprintf "%d.%02d", q$Revision: 1.6 $ =~ /: (\d+)\.(\d+)/;
-    $Revision  = '$Id: Base.pm,v 1.6 2008/11/06 18:32:33 kawas Exp $';
+    $VERSION = 0.8;
+    $Revision  = '$Id: Base.pm,v 1.1 2006/10/13 21:51:16 senger Exp $';
 
     # initiate error handling
     require Carp; import Carp qw( confess );
@@ -632,14 +629,14 @@ sub create_member {
 my $DUMPER;
 BEGIN {
     use Dumpvalue;
-    use IO::String;
+    use IO::Scalar;
     $DUMPER = Dumpvalue->new();
 #    $DUMPER->set (veryCompact => 1);
 }
 sub as_string {
     my $self = shift;
     my $dump_str;
-    my $io = IO::String->new (\$dump_str);
+    my $io = IO::Scalar->new (\$dump_str);
     my $oio = select ($io);
     $DUMPER->dumpValue (\$self);
     select ($oio);
